@@ -19,6 +19,10 @@ class Sprite:
         self.rect = pygame.Rect(self.x, self.y, self.width, self.height)
         self.window.window.blit(self.image, (self.x, self.y))
 
+    def rotate(self, angle):
+        self.image = pygame.transform.scale(self.image, (self.width, self.height))
+        self.image = pygame.transform.rotate(self.image, angle)
+
     def getWidth(self):
         return self.image.get_width()
 
